@@ -23,7 +23,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /project/tcl/src/mxedit/RCS/mxCmdUtils.c,v 2.2 1993/06/25 22:41:30 welch Exp $ SPRITE (Berkeley)";
+static char rcsid[] = "$Header: /import/tcl7/src/mxedit/RCS/mxCmdUtils.c,v 2.3 1994/02/01 18:16:20 welch Exp $ SPRITE (Berkeley)";
 #endif not lint
 
 
@@ -37,7 +37,7 @@ static char rcsid[] = "$Header: /project/tcl/src/mxedit/RCS/mxCmdUtils.c,v 2.2 1
 #include <sys/stat.h>
 
 #include "mxWidget.h"
-#include "tclHash.h"
+#include "tk.h"
 
 /*
  * The information below is used to create the command table.
@@ -1065,7 +1065,7 @@ MxDoCmd(mxwPtr, command)
     if (command == NULL) {
 	return TCL_OK;
     }
-    result = Tcl_Eval(mxwPtr->interp, command, 0, (char **) 0);
+    result = Tcl_Eval(mxwPtr->interp, command);
     if (result == TCL_OK) {
 	if (*mxwPtr->interp->result != 0) {
 	    MxOutputMsg(mxwPtr, mxwPtr->interp->result);
@@ -1170,7 +1170,7 @@ MxOutputMsg(mxwPtr, msg)
 	fprintf(stderr, "MxOutputMsg (no feedback widget): %s\n", msg);
     } else {
 	sprintf(cmd, "%s {%s}", mxwPtr->feedbackCmd, msg);
-	if (Tcl_Eval(mxwPtr->interp, cmd, 0, (char **)NULL) != TCL_OK) {
+	if (Tcl_Eval(mxwPtr->interp, cmd) != TCL_OK) {
 	    fprintf(stderr, "ERROR: %s\n", msg);
 	}
     }
