@@ -23,7 +23,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /project/tcl/src/mxedit/RCS/mxUndo.c,v 2.2 1993/06/25 22:42:16 welch Exp $ SPRITE (Berkeley)";
+static char rcsid[] = "$Header: /import/tcl7/src/mxedit/RCS/mxUndo.c,v 2.3 1994/02/01 18:17:43 welch Exp $ SPRITE (Berkeley)";
 #endif not lint
 
 
@@ -46,7 +46,7 @@ static char rcsid[] = "$Header: /project/tcl/src/mxedit/RCS/mxUndo.c,v 2.2 1993/
  */
 
 char *getenv();
-#ifdef __hpux
+#if defined(__hpux) | defined(SVR4)
 int setvbuf();
 #else
 void setbuffer();
@@ -267,7 +267,7 @@ the log.\n";
      */
 
     logPtr->buffer = malloc(512);
-#ifdef __hpux
+#if defined(__hpux) | defined(SVR4)
     setvbuf(logPtr->readStream, logPtr->buffer, _IOFBF, 512);
 #else
     setbuffer(logPtr->readStream, logPtr->buffer, 512);
@@ -1344,10 +1344,5 @@ CheckError(logPtr)
 		mxwPtr->interp->result);
     }
 
-#ifdef notdef
-    (void) Sx_Notify(mxwPtr->display, DefaultRootWindow(mxwPtr->display),
-	    -1, -1, 0, msg, mxwPtr->fontPtr,1, "Continue",
-	    (char *) NULL);
-#endif
     logPtr->flags |= DISABLED;
 }
